instrumenttools.Oboe
====================

.. abjad-lineage:: abjad.tools.instrumenttools.Oboe.Oboe.Oboe

.. autoclass:: abjad.tools.instrumenttools.Oboe.Oboe.Oboe
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.instrumenttools.Oboe.Oboe.Oboe.default_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Oboe.Oboe.Oboe.default_short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Oboe.Oboe.Oboe.effective_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Oboe.Oboe.Oboe.interval_of_transposition
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Oboe.Oboe.Oboe.is_primary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Oboe.Oboe.Oboe.is_secondary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Oboe.Oboe.Oboe.is_transposing
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Oboe.Oboe.Oboe.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Oboe.Oboe.Oboe.start_component
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Oboe.Oboe.Oboe.storage_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Oboe.Oboe.Oboe.target_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Oboe.Oboe.Oboe.traditional_pitch_range
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.instrumenttools.Oboe.Oboe.Oboe.all_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Oboe.Oboe.Oboe.instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Oboe.Oboe.Oboe.instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Oboe.Oboe.Oboe.pitch_range
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Oboe.Oboe.Oboe.primary_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Oboe.Oboe.Oboe.short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Oboe.Oboe.Oboe.short_instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Oboe.Oboe.Oboe.sounding_pitch_of_fingered_middle_c
   :noindex:

Methods
-------

.. automethod:: abjad.tools.instrumenttools.Oboe.Oboe.Oboe.attach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Oboe.Oboe.Oboe.detach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Oboe.Oboe.Oboe.get_default_performer_name
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Oboe.Oboe.Oboe.get_performer_names
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.instrumenttools.Oboe.Oboe.Oboe.__call__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Oboe.Oboe.Oboe.__delattr__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Oboe.Oboe.Oboe.__eq__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Oboe.Oboe.Oboe.__ge__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Oboe.Oboe.Oboe.__gt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Oboe.Oboe.Oboe.__hash__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Oboe.Oboe.Oboe.__le__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Oboe.Oboe.Oboe.__lt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Oboe.Oboe.Oboe.__ne__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Oboe.Oboe.Oboe.__repr__
   :noindex:
